/**
 * Copyright 2005 The Apache Software Foundation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.nutch.protocol.httpclient.innovation;

import java.util.Collections;
import java.util.HashMap;
import java.util.Map;
import java.util.Random;

import org.apache.nutch.util.NutchConf;

import HTTPClient.CookieModule;
import HTTPClient.HTTPConnection;

/**
 * HTTPClient is fully thread-safe and allows to send multiple requests through single instance of a class
 * TODO: current implementation of 'Map hosts' will be constantly growing; HTTPClient uses own threads; please add more functionality.
 * @author Fuad Efendi
 */
public class HttpFactory {

	static {
		CookieModule.setCookiePolicyHandler(null);
	}


	private static int CLIENTS_PER_HOST = NutchConf.get().getInt(
			"http.clients.per.host", 3);

	private static Map hosts = Collections.synchronizedMap(new HashMap());

	private static Random generator = new Random();

	public static synchronized HTTPConnection getConnection(String host) {

		if (!hosts.containsKey(host)) {
			HTTPConnection[] connections = new HTTPConnection[CLIENTS_PER_HOST];
			hosts.put(host, connections);
		}

		HTTPConnection[] connections = (HTTPConnection[]) hosts.get(host);

		int i = generator.nextInt(CLIENTS_PER_HOST);

		if (connections[i] == null)
			connections[i] = new HTTPConnection(host);

		return connections[i];

	}

}
